# Thedus

[Thedus](https://github.com/d-ganchar/thedus) is a lightweight migration tool for [Clickhouse](https://clickhouse.com/)

```bash
$ pip install thedus
```

<hr/>

<a href="https://pypi.org/project/thedus/" target="_blank">
    <img src="https://img.shields.io/pypi/v/thedus.svg?logo=pypi&logoColor=FFE200" alt="pypi"/>
</a>

<a href="https://www.pepy.tech/projects/thedus" target="_blank">
    <img src="https://static.pepy.tech/badge/thedus" alt="total downloads"/>
</a>
<a href="https://www.pepy.tech/projects/thedus" target="_blank">
    <img src="https://img.shields.io/pypi/dm/thedus.svg?logo=docusign&logoColor=FFE200" alt="monthly downloads"/>
</a>
<a href="https://github.com/d-ganchar/thedus/tree/main/thedus" target="_blank">
    <img src="https://img.shields.io/github/languages/code-size/d-ganchar/thedus.svg?logo=Dropbox&logoColor=ACD2F6" alt="pkg size"/>
</a>
<a href="https://github.com/d-ganchar/thedus/wiki" target="_blank">
    <img alt="Wiki" src="https://img.shields.io/badge/github-wiki-blue"/>
</a>